@@ -10,7 +10,7 @@ use App::Netdisco::Util::Web (); # for sort_port
 hook 'before' => sub {
     # list of port detail columns
     var('port_columns' => [
-        { name => 'c_admin',       label => 'Port Control',      default => ''   },
+        { name => 'c_admin',       label => 'Admin Controls',    default => ''   },
         { name => 'c_port',        label => 'Port',              default => 'on' },
         { name => 'c_descr',       label => 'Description',       default => ''   },
         { name => 'c_type',        label => 'Type',              default => ''   },
@@ -197,7 +197,12 @@ ajax '/ajax/content/device/ports' => sub {
     my $q = param('f');
     if ($q) {
         if ($q =~ m/^\d+$/) {
-            $set = $set->search({'me.vlan' => $q});
+            $set = $set->search({
+              -or => {
+                'me.vlan' => $q,
+                'port_vlans_tagged.vlan' => $q,
+              },
+            }, { join => 'port_vlans_tagged' });
             return unless $set->count;
         }
         else {
